@@ -142,6 +142,11 @@ class Field(MetricsLayerBase, SQLReplacement):
             return Set(set_definition, project=self.view.project).field_names()
         return drill_fields
 
+    @property
+    def update_where_timeframe(self):
+        # if this value is present we use it, otherwise we default to True
+        return self._definition.get("update_where_timeframe", True)
+
     def cte_prefix(self, aggregated: bool = True):
         if self.type == "cumulative":
             prefix = "aggregated" if aggregated else "subquery"
@@ -702,6 +707,12 @@ class Field(MetricsLayerBase, SQLReplacement):
                     sql_replace = field.raw_sql_query(query_type, alias_only=alias_only)
                 else:
                     sql_replace = to_replace
+                if isinstance(sql_replace, list):
+                    raise QueryError(
+                        f"Field {self.name} has the wrong type. You must use the type 'number' "
+                        f"if you reference other measures in your expression (like {to_replace} "
+                        "referenced here)"
+                    )
                 clean_sql = clean_sql.replace("${" + to_replace + "}", sql_replace)
         return clean_sql.strip()
 
